@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-extension.c,v 1.10.2.2 2006/04/09 20:24:23 chpe Exp $
+ *  $Id: ephy-adblock-extension.c,v 1.11 2006/03/16 14:59:48 chpe Exp $
  */
 
 #include "config.h"
@@ -377,7 +377,7 @@ ensure_adblocker (EphyWindow *window,
 								 EXTENSION_KEY));
 		g_return_val_if_fail (ext != NULL, NULL);
 
-		blocker = ad_blocker_new ();
+		blocker = ad_blocker_new (ext->priv->tester);
 		g_return_val_if_fail (blocker != NULL, NULL);
 
 		g_object_set_data_full (G_OBJECT (embed), AD_BLOCKER_KEY,
