@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permissions-dialog.c,v 1.3 2005/11/18 18:55:46 chpe Exp $
+ *  $Id: ephy-permissions-dialog.c,v 1.4 2006/01/22 13:51:18 crispin Exp $
  */
 
 #include "config.h"
@@ -216,7 +216,7 @@ fill_tab (DialogTab *tab)
 
 	if (tab->filled) return;
 
-	list = ephy_permission_manager_list (manager, tab->type);
+	list = ephy_permission_manager_list_permissions (manager, tab->type);
 
 	for (l = list; l != NULL; l = l->next)
 	{
@@ -314,8 +314,8 @@ delete_selection (DialogTab *tab)
 		gtk_tree_model_get_iter (model, &iter, path);
 		gtk_tree_model_get_value (model, &iter, COL_HOST, &val);
 
-		ephy_permission_manager_remove (manager, g_value_get_string (&val),
-						tab->type);
+		ephy_permission_manager_remove_permission (manager, g_value_get_string (&val),
+                                                           tab->type);
 		g_value_unset (&val);
 
 		gtk_tree_row_reference_free ((GtkTreeRowReference *)r->data);
