@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar.c,v 1.2.2.1 2005/04/14 15:30:25 chpe Exp $
+ *  $Id: ephy-sidebar.c,v 1.3 2005/04/10 18:52:19 chpe Exp $
  */
 
 #include "config.h"
@@ -413,8 +413,7 @@ ephy_sidebar_init (EphySidebar *sidebar)
 			   button_hbox);
 
 	priv->title_menu = gtk_menu_new ();
-	g_object_ref (priv->title_menu);
-	gtk_object_sink (GTK_OBJECT (priv->title_menu));
+	g_object_ref_sink (priv->title_menu);
 
 	gtk_widget_show (priv->title_button);
 	gtk_widget_show (priv->title_menu);
