@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.17.2.2 2006/05/14 19:43:58 jframeau Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.18 2006/03/23 23:15:47 jframeau Exp $
  */
 
 #include "config.h"
@@ -304,6 +304,12 @@ rebuild_ui (WindowData *data)
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyDocumentPopup",
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
+			       "SmbExtSep0", NULL,
+			       GTK_UI_MANAGER_SEPARATOR, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
+			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
+			       GTK_UI_MANAGER_MENU, FALSE);
 
 	/* Add bookmarks to input popup context */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyInputPopup",
@@ -335,6 +341,10 @@ rebuild_ui (WindowData *data)
 				       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
+		gtk_ui_manager_add_ui (manager, ui_id,
+				       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
+				       verb, verb,
+				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
 				       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
@@ -348,6 +358,10 @@ rebuild_ui (WindowData *data)
 			       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "IDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id,
+			       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
+			       GDICT_ACTION "FSIDP", GDICT_ACTION,
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id,
 			       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "INPUTP", GDICT_ACTION,
